.. _quick-start-guide-label:

*****************
Quick Start Guide
*****************

The following describes installing Presto on one or more nodes via the ``presto-admin`` software. This is an alternative to the installation steps described at `prestosql.io <https://prestosql.io/docs/current/installation.html>`_. Using the ``presto-admin`` tool is the simplest and preferred method for installing and managing a Presto cluster.

For a detailed explanation of all of the commands and their options, see :ref:`comprehensive-guide-label`.

.. toctree::
    :maxdepth: 1

    installation/presto-admin-installation
    installation/presto-admin-configuration
    installation/java-installation
    installation/presto-server-installation
    installation/presto-cli-installation
    installation/presto-catalog-installation
    installation/presto-configuration
    installation/troubleshooting-installation
    installation/presto-admin-upgrade
